# Awesome WinUI
A collection of awesome resources for WinUI / Windows developers.
[<img src="https://microsoft.github.io/microsoft-ui-xaml/img/winui-logo.png" align="right" width="170">](https://microsoft.github.io/microsoft-ui-xaml/)


[![Awesome](https://awesome.re/badge.svg)](https://awesome.re)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com)
![last commit](https://img.shields.io/github/last-commit/scottkuhl/awesome-winui?cacheSeconds=86400)

We use Releases to alert of new content, add a **Watch** to **Releases only** to get regular updates of new content.

If you are looking for WinUI 3.0 content look for this badge: [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/)

Contributions are always welcome! Please take a look at the [contribution guidelines](https://github.com/scottkuhl/awesome-winui/blob/master/contributing.md) pages first.

# Upcoming Events

**DotNetConf Event – Uno Platform and .NET 5 (December 17, 2020)**

Recently announced .NET 5 creates multiple opportunities for Uno Platform to improve performance and reduce solution complexity. With .NET 5, we are able to better target traditional Microsoft Windows targets, but also WebAssembly, Linux and macOS. Come join us for a 30 minutes overview of how Uno Platform takes advantage of .NET 5, as well as for live Q&A with our CTO Jerome Laban.

[<img src="https://img.evbuc.com/https%3A%2F%2Fcdn.evbuc.com%2Fimages%2F115649949%2F265235793343%2F1%2Foriginal.20201023-154300?w=1080&auto=format%2Ccompress&q=75&sharp=10&rect=0%2C0%2C2160%2C1080&s=8260fe311222da0b9c3a03eec978a4d8">](https://www.eventbrite.ca/e/dotnetconf-event-uno-platform-and-net-5-registration-126444369513)

## Introduction

### What is WinUI?

[WinUI](https://microsoft.github.io/microsoft-ui-xaml/) is a user interface layer that contains modern controls and styles for building Windows apps. As the native UI layer in Windows it embodies Fluent Design, giving each Windows app the polished feel that customers expect.

As of version 3.0 it has been decoupled from the underlying Windows development platforms such as WinForms, WPF and UWP.

### What We Track

This list focuses on libraries, articles, tutorials, books and other resources for building Windows application with WinUI.

## Contents
* [General](#general)
* [Libraries](#libraries)
* [Tooling](#tooling)
* [Sample Apps](#sample-apps)
* [Education](#education)
* [Channels](#channels)
* [Events](#events)
* [Podcasts](#podcasts)
* [Screencasts](#screencasts)
* [Articles](#articles)

## General

* [WinUI](https://microsoft.github.io/microsoft-ui-xaml/) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/microsoft-ui-xaml?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/microsoft-ui-xaml?cacheSeconds=86000) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) Official documentation of WinUI.  A [demo app](https://github.com/microsoft/Xaml-Controls-Gallery/tree/winui3preview) is also available.

* [Fluent Design System](https://www.microsoft.com/design/fluent/#/windows) - Make your apps feel as though they were designed with every Windows device in mind—PCs, phones, Xbox One, HoloLens, and more. Find the documentation, tools, and samples you need to get your apps published to the Microsoft Store.

* [Microsoft Learn](https://docs.microsoft.com/en-us/learn/) - Whether you're just starting or an experienced professional, Microsoft's hands-on approach helps you arrive at your goals faster, with more confidence and at your own pace.

* [UWP Community](https://uwpcommunity.com/) - The homepage for the unofficial Discord server.

* [Universal Windows Platform](https://docs.microsoft.com/en-us/windows/uwp/) - Official documentation of Universal Windows Platform, from Microsoft.

* [Windows Forms](https://docs.microsoft.com/en-us/dotnet/framework/winforms/) - Official documentation of Windows Forms, from Microsoft.

* [Windows Presentation Foundation](https://docs.microsoft.com/en-us/dotnet/framework/wpf/) - Official documentation of Windows Presentation Foundation, from Microsoft.

* [Themes of .NET](https://themesof.net/) - Track overall themes and underlying epics and user stories planned for the next major version of .NET.

## Libraries

* [Uno Platform](https://github.com/unoplatform/uno) - ![GitHub stars](https://img.shields.io/github/stars/unoplatform/uno?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/unoplatform/uno?cacheSeconds=86000) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) The Uno Platform is a Universal Windows Platform Bridge that allows UWP-based code (C# and XAML) to run on iOS, Android, macOS, and WebAssembly.

* [Windows Community Toolkit](https://github.com/windows-toolkit/WindowsCommunityToolkit/) - ![GitHub stars](https://img.shields.io/github/stars/windows-toolkit/WindowsCommunityToolkit?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/windows-toolkit/WindowsCommunityToolkit?cacheSeconds=86000) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) The Windows Community Toolkit has been working alongside the WinUI team to also make sure the Toolkit works on WinUI 3! We're happy to announce that we're also shipping a preview of the toolkit that works on top of this WinUI 3 Preview 1 the same day!

* [Project Reunion](https://github.com/microsoft/ProjectReunion) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/ProjectReunion?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/ProjectReunion?cacheSeconds=86000) Project Reunion is our vision for unifying and evolving the Windows developer platform to make it easier to build great apps that work across all the Windows 10 versions and devices people use.

* [Windows task snippets](https://github.com/microsoft/Windows-task-snippets) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/Windows-task-snippets?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/Windows-task-snippets?cacheSeconds=86000) This repo collects snippets of ready-to-use code that accomplish small but useful tasks of interest to Universal Windows Platform (UWP) app developers. These snippets represent simple solutions to common problems, and simple recipes to help you implement new app features.

* [Template10.Validation](https://github.com/Windows-XAML/Template10.Validation) - ![GitHub stars](https://img.shields.io/github/stars/Windows-XAML/Template10.Validation?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Windows-XAML/Template10.Validation?cacheSeconds=86000) These validation libraries provide UWP developers a comprehensive solution to data validation that solves problems in a realistic and usable way. The associated sample application demonstrates the use and syntax. 

* [Windows Graph Controls](https://github.com/windows-toolkit/Graph-Controls) - ![GitHub stars](https://img.shields.io/github/stars/windows-toolkit/Graph-Controls?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/windows-toolkit/Graph-Controls?cacheSeconds=86000) This is a sub-repo for the Windows Community Toolkit focused on Microsoft Graph providing a set of Helpers and Controls for development on Windows 10 with .NET.

* [Legerity](https://github.com/MADE-Apps/legerity) - ![GitHub stars](https://img.shields.io/github/stars/MADE-Apps/legerity?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/MADE-Apps/legerity?cacheSeconds=86000) Legerity is a framework for speeding up the development of automated UI testing with Appium and .NET!

* [Yugen Toolkit](https://github.com/emiliano84/Yugen.Toolkit) - ![GitHub stars](https://img.shields.io/github/stars/emiliano84/Yugen.Toolkit?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/emiliano84/Yugen.Toolkit?cacheSeconds=86000) The Toolkit is a collection of helper functions, custom controls, and app services. It helps develop common task for UWP apps.

* [Syncfusion WinUI](https://www.telerik.com/winui) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) - The Syncfusion WinUI toolkit includes feature-rich WinUI controls like DataGrid, Charts, TreeView, and more, that embodies Fluent Design for building modern and seamless Windows apps. **[$]**

* [Telerik UI for WinUI](https://www.telerik.com/winui) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) - Telerik UI for WinUI is an early experiment for the UI component suite, targeting WinUI 3.0. Its purpose is to make the development of modern and feature-rich applications faster and easier. **[$]**


## Tooling

* [Windows Template Studio](https://github.com/Microsoft/WindowsTemplateStudio) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/WindowsTemplateStudio?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/WindowsTemplateStudio?cacheSeconds=86000) Windows Template Studio (WinTS) is a Visual Studio 2019 Extension that accelerates the creation of new Universal Windows Platform (UWP) and Windows Presentation Foundation (WPF .NET Core 3.1) apps using a wizard-based experience. The resulting project is well-formed, readable code that incorporates great development features while implementing proven patterns and best practices. Sprinkled throughout the generated code we have links Docs, Stack Overflow and blogs to provide useful insights. WinTS supports creating UWP apps in C# or VB.Net and WPF (.NET Core 3.1) apps in C#.

* [Template10](https://github.com/Windows-XAML/Template10) - ![GitHub stars](https://img.shields.io/github/stars/Windows-XAML/Template10?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Windows-XAML/Template10?cacheSeconds=86000) Template 10 is a set of Visual Studio project templates. They sling-shot developer productivity by getting ~80% of the boilerplate stuff delivered in the template - things like navigation, suspension, and even a Hamburger control.

* [Fluent XAML Theme Editor](https://github.com/microsoft/fluent-xaml-theme-editor) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/fluent-xaml-theme-editor?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/fluent-xaml-theme-editor?cacheSeconds=86000) This repo contains the full solution and source code to the Fluent XAML Theme Editor - a tool that helps demonstrate the flexibility of the Fluent Design System as well as supports the app development process by generating XAML markup for our ResourceDictionary framework used in Universal Windows Platform (UWP) applications.

* [Rapid XAML Toolkit](https://github.com/mrlacey/Rapid-XAML-Toolkit) - ![GitHub stars](https://img.shields.io/github/stars/mrlacey/Rapid-XAML-Toolkit?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/mrlacey/Rapid-XAML-Toolkit?cacheSeconds=86000) This is a collection of tools for making it easier for developers to work with XAML (UWP, WPF, and Xamarin.Forms).

* [Windows app bootstrap template](https://github.com/dpaulino/windows-app-bootstrap) - ![GitHub stars](https://img.shields.io/github/stars/dpaulino/windows-app-bootstrap?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/dpaulino/windows-app-bootstrap?cacheSeconds=86000) A simple template repository you can use to fast track your new modern Windows app.

* [UWP Essentials](https://github.com/mrlacey/UwpEssentials) - ![GitHub stars](https://img.shields.io/github/stars/mrlacey/UwpEssentials?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/mrlacey/UwpEssentials?cacheSeconds=86000) The easiest way to set up Visual Studio for the ultimate UWP development experience.

* [Character Map UWP](https://www.microsoft.com/en-us/p/character-map-uwp/9wzdncrdxf41) - A modern, native UWP replacement for the Win32 Character Map and Windows Font Viewer with flawless high DPI and touch support.

* [UWP Resources Gallery](https://www.microsoft.com/en-us/p/uwp-resources-gallery/9pjjl433vx9r) - This app aims to provide an interactive demo of common UWP resources such as the Segoe MDL2 icons, system colors and system brushes.

* [Visual Asset Generator](https://www.microsoft.com/en-us/p/visual-asset-generator/9mz6qrqtdkf2) - An app designed to make creating Icons and Visual Assets for UWP apps a breeze.

* [XAML Studio](https://www.microsoft.com/en-us/garage/profiles/xaml-studio/) - XAML Studio, a Microsoft Garage project will help you rapidly prototype UWP XAML that can be easily copied into your app in Visual Studio. XAML Studio lets you preview your XAML code in real-time and interact with the result just like it was running in your own app!

## Sample Apps

* [Universal Windows Platform (UWP) app samples](https://github.com/microsoft/Windows-universal-samples) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/Windows-universal-samples?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/Windows-universal-samples?cacheSeconds=86000) This repo contains the samples that demonstrate the API usage patterns for the Universal Windows Platform (UWP) in the Windows Software Development Kit (SDK) for Windows 10. These code samples were created with the Universal Windows Platform templates available in Visual Studio, and are designed to run on desktop, mobile, and future devices that support the Universal Windows Platform.

* [Windows Composition Samples](https://github.com/microsoft/WindowsCompositionSamples) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/WindowsCompositionSamples?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/WindowsCompositionSamples?cacheSeconds=86000) This is the place for the latest code samples, demos, and developer feedback around building beautiful and engaging Universal Windows Platform apps. This repo focuses on the platform-building blocks that make up the Fluent Design System, with emphasis on creating UI using APIs in the Windows.UI.Composition namespace. The code samples and demos in this repo are targeted at developers who are interested in experimenting, building, and providing feedback on the latest flighting Windows UI APIs.

* [XAML Controls Gallery](https://github.com/microsoft/Xaml-Controls-Gallery/) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/Xaml-Controls-Gallery?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/Xaml-Controls-Gallery?cacheSeconds=86000) Shows all of the XAML controls in an interactive format. This app is the interactive companion to the Fluent Design Guidelines and shows the usage of both UWP Xaml APIs and Windows UI Toolkit APIs.

* [UWP Experiences - app samples](https://github.com/microsoft/uwp-experiences) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/uwp-experiences?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/uwp-experiences?cacheSeconds=86000) The UWP App Experiences are beautiful, cross device, feature rich and functional app samples built to demonstrate realistic app scenarios on the UWP platform across desktop, Xbox, mobile, and more. Besides being open source on GitHub, each sample is published to the Windows Store for easier access for developers and each is accompanied with at least one blog post and short overview video.

* [XAML VanArsdel Inventory Sample](https://github.com/microsoft/InventorySample) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/InventorySample?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/InventorySample?cacheSeconds=86000) This repo showcases a sample Windows 10 application (using the Universal Windows Platform) focused in Line of Business scenarios, showing how to use the latest Windows capabilities in Desktop applications. The sample is based around creating and managing customer, orders, and products for the fictitious company VanArsdel.

* [BuildCast Video Player UWP Sample](https://github.com/Microsoft/BuildCast) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/BuildCast?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/BuildCast?cacheSeconds=86000) BuildCast is an end-to-end sample built to showcase the Microsoft Fluent Design System as well as other capabilities of the Universal Windows Platform. It permits browsing, downloading and playback of select video podcasts including a sampling of the most popular ones from Channel 9 as well as some popular Windows tech enthusiast feeds. It has other features such as ink notes, bookmarks and remote playback. This sample was initially shown and discussed at the 2017 Build conference during the Build Amazing Apps with Fluent Design talk.

* [Customers Orders Database sample](https://github.com/Microsoft/Windows-appsample-customers-orders-database) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-customers-orders-database?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-customers-orders-database?cacheSeconds=86000) A UWP (Universal Windows Platform) sample app showcasing features useful to enterprise developers, like Azure Active Directory (AAD) authentication, UI controls (including a data grid), Sqlite and SQL Azure database integration, Entity Framework, and cloud API services. The sample is based around creating and managing customer accounts, orders, and products for the fictitious company Contoso.

* [RSS Reader sample](https://github.com/Microsoft/Windows-appsample-rssreader) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-rssreader?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-rssreader?cacheSeconds=86000) A mini-app for retrieving RSS feeds and viewing articles, showing MVVM and design best practices. Users can specify the URL of a feed, view articles in a WebView control, and save favorite articles to local storage.

* [Lunch Scheduler app](https://github.com/Microsoft/Windows-appsample-lunch-scheduler) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-lunch-scheduler?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-lunch-scheduler?cacheSeconds=86000) Lunch Scheduler is a Universal Windows Platform (UWP) sample that schedules lunches with your friends and coworkers. You can invite friends to a restaurant of interest and the app takes care of the lunch management for all involved parties.

* [Family Notes sample](https://github.com/Microsoft/Windows-appsample-familynotes) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-familynotes?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-familynotes?cacheSeconds=86000) A mini-app that explores different input modalities and scenarios of user awareness. A bulletin-board app that allows family members to leave notes for each other on a common PC/tablet just like they would on a bulletin board. Using text, speech, ink, or pictures, a user can create a note and tag it for another user. Later when that other user approaches the PC/Tablet, the app uses imaging APIs and the Microsoft Cognitive Services (Face API) to detect their presence and display the notes that have been left for them, effectively filtering based on facial recognition. While the app is open, users can naturally interact with it using speech (“Add note for Bob”). If the app isn’t open, a user can easily launch it and interact with it using Cortana.

* [Coloring Book sample](https://github.com/Microsoft/Windows-appsample-coloringbook) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-coloringbook?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-coloringbook?cacheSeconds=86000) A mini-app that demonstrates the versatility of Windows Ink (including the Windows Ink Toolbar) and radial controller (for Wheel devices such as the Surface Dial) features.

* [VanArsdel UWP Sample](https://github.com/microsoft/VanArsdel) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/VanArsdel?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/VanArsdel?cacheSeconds=86000) VanArsdel is an end-to-end sample built to showcase the Microsoft Fluent Design System as well as other capabilities of the Universal Windows Platform. It allows the user to browse the virtual "store" of lamps that can be organized and decorated.

* [Photo Editor C++/WinRT sample](https://github.com/Microsoft/Windows-appsample-photo-editor) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-photo-editor?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-photo-editor?cacheSeconds=86000) The Photo Editor application is a Universal Windows Platform (UWP) sample that showcases development with the C++/WinRT language projection. The sample application allows you to retrieve photos from the Pictures library, and then edit the selected image with assorted photo effects. In the sample's source code, you'll see a number of common practices—such as data binding, and asynchronous actions and operations—performed using the C++/WinRT projection.

* [Photo Lab sample](https://github.com/Microsoft/Windows-appsample-photo-lab) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-photo-lab?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-photo-lab?cacheSeconds=86000) A mini-app for viewing and editing image files, demonstrating XAML layout, data binding, and UI customization features for Universal Windows Platform (UWP) apps.

* [MVVM Toolkit Samples](https://github.com/windows-toolkit/MVVM-Samples) - ![GitHub stars](https://img.shields.io/github/stars/windows-toolkit/MVVM-Samples?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/windows-toolkit/MVVM-Samples?cacheSeconds=86000) The Microsoft.Toolkit.Mvvm package is a modern, fast, and modular MVVM library. It is built around the following principles: Platform and Runtime Independent, Simple to pick-up and use, À la carte, Reference Implementation.

* [UWP Demo for Insider Dev Tour 2019](https://github.com/microsoft/InsiderDevTourDemos19/tree/master/Sessions/ui) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/InsiderDevTourDemos19?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/InsiderDevTourDemos19?cacheSeconds=86000) This repo contains a demo UWP app that is built for demostrating rich controls and libraries from Windows UI Library and Windows Community Toolkit.

* [Hue Lights sample](https://github.com/Microsoft/Windows-appsample-huelightcontroller) - ![GitHub stars](https://img.shields.io/github/stars/Microsoft/Windows-appsample-huelightcontroller?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/Microsoft/Windows-appsample-huelightcontroller?cacheSeconds=86000) A mini-app that explores integrating Windows features with intelligent home automation. Specifically, it shows how you can use Cortana and Bluetooth Low Energy (Bluetooth LE) to create an interactive experience with the Phillips Hue Lights (a Wi-Fi enabled lighting system).

* [Quiz Game Sample](https://github.com/microsoft/Windows-appsample-remote-system-sessions) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/Windows-appsample-remote-system-sessions?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/Windows-appsample-remote-system-sessions?cacheSeconds=86000) A pub-style trivia game sample for the Universal Windows Platform (UWP) demonstrating the Remote System Session API (part of the Project Rome platform).

* [Uno Samples](https://github.com/unoplatform/Uno.Samples) - ![GitHub stars](https://img.shields.io/github/stars/unoplatform/Uno.Samples?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/unoplatform/Uno.Samples?cacheSeconds=86000) This repository provides simple to-the-point samples for features of the Uno platform.

* [Contoso Insurance UWP App](https://github.com/microsoft/WDD-Spring-2018) - ![GitHub stars](https://img.shields.io/github/stars/microsoft/WDD-Spring-2018?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/microsoft/WDD-Spring-2018?cacheSeconds=86000) This UWP app was designed to showcase how Fluent Design, Windows Timeline and Adaptive Cards work together on the Windows Developer Day 2018.

* [Fluent Store](https://github.com/yoshiask/FluentStore) - ![GitHub stars](https://img.shields.io/github/stars/yoshiask/FluentStore?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/yoshiask/FluentStore?cacheSeconds=86000) A Fluent, native, and open-source alternative to the Microsoft Store app.

* [Ch9](https://github.com/unoplatform/Uno.Ch9) - ![GitHub stars](https://img.shields.io/github/stars/unoplatform/Uno.Ch9?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/unoplatform/Uno.Ch9?cacheSeconds=86000) [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) Ch9 is a demo app which showcases the power of using WinUI and Uno Platform for developing single-codebase, cross-platform applications for Windows, iOS, Android and WebAssembly. It uses the publicly-available video feed from Microsoft's Channel 9 for content.  The app is also available in App Stores ([Microsoft](https://www.microsoft.com/store/productId/9NL3GNG31TMK), [Apple](https://apps.apple.com/us/app/ch9/id1512235875?ls=1), [Google](https://play.google.com/store/apps/details?id=uno.platform.ch9&hl=en)).

* [UWP IEXCloud Sample](https://github.com/XamlBrewer/UWP-IEXCloud-Sample) - ![GitHub stars](https://img.shields.io/github/stars/XamlBrewer/UWP-IEXCloud-Sample?cacheSeconds=604800) ![GitHub last commit](https://img.shields.io/github/last-commit/XamlBrewer/UWP-IEXCloud-Sample?cacheSeconds=86000) An attempt to build a representative and useful WinUI reference app.  The [announcement article](https://xamlbrewer.wordpress.com/2020/06/16/a-winui-2-reference-app/) can be found here.

## Education

Education are listed by newest date first.

* Learn WinUI 3.0 [![Generic badge](https://img.shields.io/badge/WinUI-3-blue.svg)](https://shields.io/) - (Fall 2020) - Alvin Ashcraft, Packt Publishing - [Early announcement](https://www.winui.tips/2020/02/learn-winui-30-my-new-book-to-be.html).
* [Introduction to Uno Platform](https://www.udemy.com/course/introduction-to-uno-platform/?referralCode=C9FE308096EADFB5B661) - (August 2020) - Christian Findlay, Udemy - Build Single-Source WebAssembly, Mobile and Desktop Apps with C#.

## Channels

[<img src="https://static-cdn.jtvnw.net/jtv_user_pictures/8d74b374-2335-448d-9e3d-f7f27841ef04-profile_image-70x70.png">](https://www.twitch.tv/xamlllama) 
[<img src="https://static-cdn.jtvnw.net/jtv_user_pictures/23bc51a7-bf03-41f5-9e98-9f5ed9d2ecc0-profile_image-70x70.png">](https://www.twitch.tv/visualstudio) 
[<img src="https://static-cdn.jtvnw.net/jtv_user_pictures/e98df394-1bee-43c0-9f5f-78a63148a84b-profile_image-70x70.png">](https://www.twitch.tv/dotnetnorthlive) 
[<img src="https://static-cdn.jtvnw.net/jtv_user_pictures/9590f1ae-c091-4bba-b07c-2bbc3400ac28-profile_image-70x70.png">](https://www.twitch.tv/martinzikmund) 

## Events

Events are listed by newest date first.

* [DotNetConf Event – Uno Platform and .NET 5](https://www.eventbrite.ca/e/dotnetconf-event-uno-platform-and-net-5-registration-126444369513) - (December 17, 2020) -  Recently announced .NET 5 creates multiple opportunities for Uno Platform to improve performance and reduce solution complexity. With .NET 5, we are able to better target traditional Microsoft Windows targets, but also WebAssembly, Linux and macOS. Come join us for a 30 minutes overview of how Uno Platform takes advantage of .NET 5, as well as for live Q&A with our CTO Jerome Laban.

* [UnoConf](https://unoconf.com/) - (August 12, 2020) -  An online conference for the complete Uno community – engineering team, influencers, code contributors as well as those wishing to learn more about it. UnoConf 2020 brings together speakers from Microsoft, our core team and community for a ½ day online event.

* [Microsoft Build](https://mybuild.microsoft.com/) - (May 19 - 20, 2020) -  48-hours of non-stop developer goodness generates amazing content—and you helped bring it to life.

* [Microsoft 365 Developer Day](https://developer.microsoft.com/en-us/microsoft-365/virtual-events) - (February 11th, 2020 8:30AM PDT) - Focused on dual-screen experiences. The keynote and sessions will show how to: Get the most out of these SDKs and emulators, Use cross platform tools and languages, Design apps for dual-screen devices, Build dual-screen experiences on the web, Connect your apps with Microsoft 365.

## Podcasts

Podcasts are listed by newest date first.

* [Michael Hawker on the Windows Community](http://azuredevopspodcast.clear-measure.com/michael-hawker-on-the-windows-community-episode-118) - (December 7, 2020) - Azure DevOps Podcast - ![duration](https://img.shields.io/badge/Duration:%20-37%20min-%230094FF?cacheSeconds=maxAge&logo=pocket-casts) In this episode, Michael A. Hawker, AKA ‘XAML Llama,’ joins the podcast to discuss the Windows Community Toolkit and more.

* [Uno Platform With Jérôme Laban](https://dotnetcore.show/episode-60-uno-platform-with-jerome-laban/) - (September 18, 2020) - The .NET Core Podcast - ![duration](https://img.shields.io/badge/Duration:%20-42%20min-%230094FF?cacheSeconds=maxAge&logo=pocket-casts) In this episode I spoke with Jérôme about precisely what Uno Platform is, how it's more than just an alternative to Xamarin, and how you can use it to build cross platform UI-based .NET applications which leverage all of the APIs that you have come to love and expect.

* [Update on Uno. With Jérôme Laban](https://kerry.lothrop.de/devtalk-43/) - (August 10, 2020) - DevTalk - ![duration](https://img.shields.io/badge/Duration:%20-38%20min-%230094FF?cacheSeconds=maxAge&logo=pocket-casts) On episode 43 of DevTalk I welcome Jérôme Laban for a second time to talk about what has happened with the Uno Platform since we last spoke.

* [Building Apps using Uno with Kenzie Whalen](https://www.dotnetrocks.com/?show=1689) - (May 28, 2020) - .NET Rocks! - ![duration](https://img.shields.io/badge/Duration:%20-51%20min-%230094FF?cacheSeconds=maxAge&logo=pocket-casts) What's your cross-platform development solution? Carl and Richard talk to Kenzie Whalen about the Uno Platform, where you write C# and XAML for Windows and are able to deploy via Xamarin to iOS and Android... and to browsers via WebAssembly also! The conversation digs into how UWP is evolving, and the approaches you can take to keep your codebase as common as possible between all the platforms. But there are always variations from platform-to-platform. Kenzie also talks about how some of the new hardware, like Surface Duo, will impact development - more cool stuff is coming!

* [Ryan Demopoulos on WinUI](http://azuredevopspodcast.clear-measure.com/ryan-demopoulos-on-winui-episode-80) - (March 16, 2020) - The Azure DevOps Podcast - ![duration](https://img.shields.io/badge/Duration:%20-40%20min-%230094FF?cacheSeconds=maxAge&logo=pocket-casts) In this episode, Jeffrey and Ryan discuss WinUI in-depth. Ryan explains what it is, the changes and developments he has seen (and been a part of) over the course of his career, where he sees it heading in 10 years time, details of the release roadmap, cross-platform development, what the team is currently working on — and a whole lot more!

* [Client-Side Development in 2020 with Brian Lagunas](https://www.dotnetrocks.com/?show=1672) - (January 30, 2020) - .NET Rocks! - ![duration](https://img.shields.io/badge/Duration:%20-60%20min-%230094FF?cacheSeconds=maxAge&logo=pocket-casts) It's 2020 - how do you build client-side applications? Carl and Richard talk to Brian Lagunas about his work in client-side development, largely around XAML (don't worry WinForms, we still love you!) - WPF, UWP and Xamarin.Forms. Brian leads the Prism open-source project that helps to build XAML-based applications, specifically WPF and Xamarin.Forms. The conversation digs into the problems around UWP and even a mention of Silverlight - and then the challenges of the other client-side platform, mobile!

* [XAML Tooling with Dmitry Lyalin](https://www.dotnetrocks.com/?show=1669) - (January 9, 2020) - .NET Rocks! - ![duration](https://img.shields.io/badge/Duration:%20-57%20min-%230094FF?cacheSeconds=maxAge&logo=pocket-casts) How do you write XAML? Carl and Richard chat with Dmitry Lyalin about Microsoft's on-going efforts to make coding in XAML faster, easier and more reliable. Dmitry starts out talking about how there are different dialects of XAML, including WPF, UWP, Xamarin Forms and more - although there are concerted efforts to keep them more in sync. And that helps with tooling also! Dmitry dives into Blend, XAML Designer and the power of coding XAML directly with IntelliCode, hot-reload and more!

## Screencasts

Screencasts are listed by newest date first.

All .NET Community Standups are listed on [Microsoft .NET Community Standups](https://dotnet.microsoft.com/platform/community/standup).

**WinUI Community Call Occurs the 3rd Wednesday of every month at 9:00AM PDT**

[<img src="https://github.com/scottkuhl/awesome-winui/blob/main/Images/Community%20Call.png?raw=true">](https://www.youtube.com/channel/UCzLbHrU7U3cUDNQWWAqjceA)

* [App Consult Insights - S02 E05 The UNO platform](https://www.youtube.com/watch?v=lztiTlXXq-0) - (December 11, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-21%20min-%230094FF?cacheSeconds=maxAge&logo=youtube) Matteo and Marc are back with an episode about their favourite topic: WinUI 3. But this time we look beyond the core framework and explore what the UNO platform has to offer for cross-platform WinUI 3 development.

* [App Consult Insights - S02 E04 WinUI 3.0 Preview 3.0](https://www.youtube.com/watch?v=xUdTpoyINvc) - (November 19, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-10%20min-%230094FF?cacheSeconds=maxAge&logo=youtube) The WinUI team has just released a new and exciting preview of WinUI 3.0, the new UI framework to build Windows applications. In this short episode, Marc and Matteo shares some highlights of this new release, like the Intellisense support and XAML Hot Reload.

* [App Development Community Standup: WinUI 3 Preview 3 release](https://www.youtube.com/watch?v=aerGF9kqMJY) - (November 17, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-52%20min-%230094FF?cacheSeconds=maxAge&logo=youtube) Join Kevin Gallo and guests to learn about the new features in the WinUI 3 Preview 3 that are available for you to try in your app.

* [Come meet the new .NET Standard MVVM](https://www.twitch.tv/videos/707332546) - (August 11, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-66%20min-%230094FF?cacheSeconds=maxAge&logo=twitch).

* [WinUI 3 & the Windows Community Toolkit Preview](https://www.twitch.tv/videos/700998018) - (August 4, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-52%20min-%230094FF?cacheSeconds=maxAge&logo=twitch).

* [App Development Community Standup: Project Reunion Update](https://www.youtube.com/watch?v=50PGkfLNDoQ) - (July 17, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-55%20min-%230094FF?cacheSeconds=maxAge&logo=youtube) Join Kevin Gallo and guests to learn more about how to contribute to Project Reunion, our next steps, and ask your questions live.

* [Building apps for 1 billion Windows 10 Desktops and expanding reach even further with Windows Virtual Desktop](https://mybuild.microsoft.com/sessions/db7c338d-3ba6-4c89-8713-2fdf5807a3b6?source=sessions) - (May 20, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-38%20min-%230094FF?cacheSeconds=maxAge&logo=microsoft) Learn how to take advantage of incredible Windows technologies like WinUI3 and MSIX to target the 1 billion+ in-market Windows 10 devices, and to reach billions of other devices via Windows Virtual Desktop.

* [Fluent Design System - Building apps that feel natural on every device](https://mybuild.microsoft.com/sessions/f6c1b5fc-050f-4b23-bcab-498a0777bf79?source=sessions) - (May 20, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-34%20min-%230094FF?cacheSeconds=maxAge&logo=microsoft) Leverage Microsoft 365 UI libraries to efficiently build your own productivity UX across devices and platforms using Fluent UI React, React Native, Mobile, and WinUI open source control libraries. Get a sneak peek of our plans for the Fluent Design System.

* [WebView2: Bringing the best of the web to your native apps](https://mybuild.microsoft.com/sessions/57e81665-3dd6-45ad-8cc2-6d6f742cc39c?source=sessions) - (May 20, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-27%20min-%230094FF?cacheSeconds=maxAge&logo=microsoft) Developers wanting to maximize code reusability in a multi-platform multi-device world are betting more and more on web technologies. WebView2 enables hosting web content in native applications while using the Microsoft Edge (Chromium) rendering engine. In this session, you'll learn about WebView2 and its roadmap, as well as how to get started using it in your application, including Win32 C/C++, .NET (WPF/WinForms), or WinUI 3.0 apps.  [Second Session](https://mybuild.microsoft.com/sessions/2118150e-250b-4a7f-94dd-2a23db4bd7df?source=sessions) also available.

* [Everything you need to know about WinUI](https://mybuild.microsoft.com/sessions/b0300eb4-a462-48ec-956d-7caa18470e3c?source=sessions) - (May 20, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-30%20min-%230094FF?cacheSeconds=maxAge&logo=microsoft) WinUI is Microsoft’s UI framework of the future for every app on Windows, designed to work in both Universal (UWP) and Desktop (Win32) apps.  Come learn how WinUI provides a path forward for every Windows Developer, whether you’re using WinForms, WPF, MFC, native or .NET, and more!  Replays [Session B](https://mybuild.microsoft.com/sessions/7d5b56db-d367-43ac-9163-44de4e3919e8?source=sessions) and [Session 3](https://mybuild.microsoft.com/sessions/11720456-1481-4493-a2a2-d87d7985a540?source=sessions) also available.

* [If I'm writing a new Windows client app today, what technology should I use? | One Dev Question](https://www.youtube.com/watch?v=uG0riz00i8s) - (April 9, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-1%20min-%230094FF?cacheSeconds=maxAge&logo=youtube) Some great insight and useful tips for building an app today from Kevin Gallo.

* [Is Microsoft promoting UWP, Win32, or Web? | One Dev Question](https://www.youtube.com/watch?v=DUTI6W87OuE) - (April 7, 2020) - ![duration](https://img.shields.io/badge/Duration:%20-1%20min-%230094FF?cacheSeconds=maxAge&logo=youtube) So UWP? Or Win32?  Or the Web?  What should you use for your next app?  Kevin Gallo, @kevintgallo, explains in today's One Dev Question.

## Articles

Articles are listed by newest date first.

* [Modernizing your .NET app with WinUI3](https://blogs.msmvps.com/bsonnino/2020/12/23/modernizing-your-net-app-with-winui3/) - (December 23, 2020) - In the last post I showed how to use Xaml Islands to modernize your .NET app. As you could see, there are a lot of steps and the procedure is a little clumsy. But now it’s getting better, Microsoft has introduced WinUI 3 and, with that, things are getting better: you don’t need special components to add your WinUI code, you can use the WinUI components directly in you app.

* [Top 10 Uno Platform developments to look forward to in 2021](https://platform.uno/blog/top-10-uno-platform-developments-to-look-forward-to-in-2021/) - (December 23, 2020) - December is usually dominated by top-10 lists for the year that is about to pass. While Uno-wise we had a great 2020, we’d rather look forward to 2021 and define what will make it great. This list is a compilation of our team wishes, as well as early looks at the data we are gathering from our 2021 roadmap survey (still open btw).

* [Uno Platform 3.4 – Maturing the supported control set](https://platform.uno/blog/uno-platform-3-4-maturing-the-supported-control-set/) - (December 22, 2020) - In early parts of 2020 we had released support for many new platforms – macOS, Linux, Skia and flirted with Tizen. In the second half of the year, as WinUI matured more, we focused on providing day-0 support for WinUI releases. Starting from today’s 3.4 release and in the period ahead when WinUI is expected to RTM, we will be putting an even bigger focus on maturing Uno Platform by providing a growing set of controls and mappings to existing WinUI and 3rd party components.

* [Uno Platform 2021 Roadmap Survey](https://platform.uno/blog/uno-platform-2021-roadmap-survey/) - (December 17, 2020) - TLDR: Take Uno Platform 5-minute Survey now to help us decide 2021 priorities.

* [Windows Template Studio 3.9 Released](https://github.com/microsoft/WindowsTemplateStudio/releases/tag/3.9.20351.02) - (December 17, 2020) - Version 3.9 of Windows Template Studio is now available with test projects for WPF, accessibility updates, bug fixes and NuGet package reference updates.

* [Infragistics announces Uno Platform specific UI Controls](https://platform.uno/blog/infragistics-announces-uno-platform-specific-ui-controls/) - (December 16, 2020) - We are happy to announce that Infragistics, a UI control ‘household’ name with 30+ years of experience in providing productivity UI controls for .NET developers is releasing their initial offering for Uno Platforms consisting of Grids, Charts and Gauges. In addition to Uno Platform-specific controls, Infragistics also announced support for WinUI!

* [Windows 10: Microsoft's Project Reunion preview arrives to make writing apps easier](https://www.zdnet.com/article/windows-10-microsofts-project-reunion-preview-arrives-to-make-writing-apps-easier/) - (December 14, 2020) - Microsoft makes progress on its plan to bring old Windows apps together with modern ones.

* [Announcing Project Reunion V0.1!](https://github.com/microsoft/ProjectReunion/issues/337) - (December 11, 2020) - V0.1 is just the beginning. This limited preview lays the foundation for Project Reunion’s runtime distribution and includes some of the work we’ve done towards creating the plumbing that makes sure your apps can consume Project Reunion APIs. There’s still more to do, to unify the platform, add more functionality such as Windowing and Storage APIs that will be released in the coming months, and do performance tuning. We will be publishing a more detailed roadmap in the new year, 2021.

* [Porting the Contoso UWP showcase application to Uno Platform](https://platform.uno/blog/porting-the-contoso-uwp-showcase-application-to-uno-platform/) - (December 8, 2020) - Connor Park, a Microsoft MVP and blogger from Korea recently ported the Contoso showcase application from being desktop-only, UWP application to a cross-platform application using UWP and Uno Platform. The source code is available in GitHub for you to try and learn from it. Equally importantly, Connor took the time to capture lessons learned during the port in order to help all others wishing to move their UWP desktop applications to Web, macOS, Linux, iOS and Android.

* [Microsoft’s PowerToys for Windows 10 will get a contemporary replace with new options](https://enter21st.com/microsofts-powertoys-for-windows-10-will-get-a-contemporary-replace-with-new-options/) - (December 2, 2020) - With at present’s replace, Microsoft is bringing Windows 10’s Fluent UI to the picture resizer. It makes use of each Fluent Design and ModernWPF to imitate the WinUI feel and look, and the replace additionally allows assist for themes.

* [Windows UI Library 2.5](https://docs.microsoft.com/en-us/windows/apps/winui/winui2/release-notes/winui-2.5?view=winui-2.5) - (December 1, 2020) - Win UI 2.5 has been released with new features including a new InfoBar control, a Determinate ProgressRing and the ability to add footer menu items to the NavigatioView.

* [What’s the correlation between .NET 5, WinUI and MAUI (Xamarin.Forms)](https://nicksnettravels.builttoroam.com/net5-crossplatform/) - (December 1, 2020) - Over the last couple of years there have been a couple of key developments in the .NET world. However, despite a lot of rhetoric from Microsoft about building a better developer ecosystem, the reality is that the current landscape for building apps using .NET is a mess and no amount of sugar coating is going to fix that. In this post I’m going to try to position a number of technologies in the hope that I can share where I think things are going.

* [Uno Platform 3.3 – Day 0 support for WinUI 3 Preview 3, Android 11](https://platform.uno/blog/uno-platform-3-3-day-0-support-for-winui-3-preview-3-android-11/) - (November 17, 2020) - WinUI 3.0 Preview 3 is a big step towards shipping the final version of WinUI. We at Uno Platform team are happy to report that Uno Platform already works with the latest WinUI preview. Our sincerest thanks to WinUI team who keeps us posted on their progress and allows us to make modifications to Uno so that our joint developer base can use the latest and greatest bits right away.

* [Announcing WinUI 3: Preview 3](https://blogs.windows.com/windowsdeveloper/2020/11/17/announcing-winui-3-preview-3/) - (November 17, 2020) - If you tuned in to this morning’s App Development Community Standup, you know that today we released WinUI 3 Preview 3.

* [A lap around the Microsoft MVVM Toolkit](https://xamlbrewer.wordpress.com/2020/11/16/a-lap-around-the-microsoft-mvvm-toolkit/) - (November 16, 2020) - In this article we’ll walk through a UWP sample app to experiment with the features of the new Microsoft.Toolkit.Mvvm package that is part of the Microsoft Community Toolkit.

* [Start and Restart Windows (UWP/WinUI) Applications on Windows Startup](https://nicksnettravels.builttoroam.com/launch-on-startup/) - (November 14, 2020) - A while ago Windows introduced a little-known feature that allows applications to automatically restart when Windows is restarted. However, rather than just look at this feature, which Windows app developer get for free, in this post we’re going to look at different options for starting and restarting a Windows application when Windows starts/restarts.

* [Uno Platform 3.2: .NET 5, C# 9 support and .NET 5 WebAssembly AOT Support](https://platform.uno/blog/uno-platform-3-2-net-5-c-9-support-and-net-5-webassembly-aot-support/) - (November 9, 2020) - The 3.2 release is loaded with features and performance improvements. Most of the release focused on upcoming .NET 5 and all benefits Uno Platform gets from building on top of it. However, we are also releasing improvements to the controls and tooling we introduced in previous releases.

* [Syncfusion Previews WinUI Controls](https://visualstudiomagazine.com/articles/2020/11/04/syncfusion-3.aspx) - (November 4, 2020) - Syncfusion's latest update to its various third-party development controls and tools provides preview support for WinUI, Microsoft's UI framework for all Windows apps across both Win32 and Universal Windows Platform (UWP).

* [Beyond Uno Platform “Getting Started” – Navigation, Platform Specific XAML and C#, MVVM, JavaScript interop and more](https://platform.uno/blog/beyond-uno-platform-getting-started-navigation-platform-specific-xaml-and-c-mvvm-javascript-interop-and-more/) - (November 2, 2020) - Andrew Hoefling, a Microsoft MVP, speaker, trainer and as of recently Uno Platform contributor dedicated a blog series with getting started guides and code samples to help you get up and running quickly with Uno Platform Apps.

* [Microsoft plans big Windows 10 UI refresh in 2021 codenamed 'Sun Valley'](https://www.windowscentral.com/windows-10-sun-valley-ui-october-2021-update) - (October 28, 2020) - A big UI refresh is on the cards for Windows 10 in 2021. The project is codenamed Sun Valley. Improvements to File Explorer, Start, and Tablet Mode are expected.

* [Uno Platform 3.1 Released – Linux, new WinUI controls, Prism 8.0 and more](https://platform.uno/blog/uno-platform-3-1-released-linux-new-winui-controls-prism-8-0-and-more/) - (October 23, 2020) - For 3.1 release we were able to add 70+ features and close 140+ code and documentation issues. Let’s unpack the release. And for all of you inpatient ones, head over to your IDE and update your packages to 3.1!

* [Announcing Microsoft Edge WebView2 General Availability](https://blogs.windows.com/msedgedev/2020/10/19/edge-webview2-general-availability/) - (October 19, 2020) - Today, we are excited to announce that  Microsoft Edge WebView2 for Win32 C/C++ is generally available and ready for use in production applications! With today’s announcement, we are officially releasing a forward-compatible WebView2 SDK along with production-ready WebView2 Runtime. These can be used in any Win32 C/C++ application, and are supported across existing Windows versions.

* [Building cross-platform apps with .NET and Uno](https://www.red-gate.com/simple-talk/dotnet/net-development/building-cross-platform-apps-with-net-and-uno/) - (October 19, 2020) - You can use Xamarin to develop .NET apps to run on iOS or Android instead of Windows. In this article, Julio Sampaio demonstrates the Uno Platform. You can build cross-platform applications using Uno which has even more options.

* [MVVM Toolkit Preview 3 & The Journey of an API](https://devblogs.microsoft.com/pax-windows/mvvm-toolkit-preview-3-the-journey-of-an-api/) - (October 7, 2020) - 🎉 Today we’re happy to announce a new preview of our MVVM Toolkit as part of the Windows Community Toolkit. 🎉 This update includes changes based on feedback from our community who’ve been using the initial preview of the library.

* [Introduction to WebAssembly for .NET Developers: Building with Uno Platform, XAML, and C#](https://platform.uno/blog/introduction-to-webassembly-for-net-developers-building-with-uno-platform-xaml-and-c/) - (October 7, 2020) - I’ll show you how to build a web application utilizing WebAssembly with .NET, XAML, and C#. You’ll build a simple XAML app with some form controls to collect data and display that data in a ListView.

* [Build pixel-perfect Microsoft Surface Duo apps with Uno Platform](https://devblogs.microsoft.com/surface-duo/get-started-uno-platform/) - (September 29, 2020) -  In previous blog posts, the Surface Duo team demonstrated how you can build dual-screen apps using Java and Kotlin, Xamarin and C#, Flutter, React Native, Web, and games with Unity. Today’s blog post shows how UWP and WinUI developers can target the Surface Duo using Uno Platform.

* [Uno Platform 3.0 – Styling Uno Applications with Fluent and Material styles](https://platform.uno/blog/uno-platform-3-0-styling-uno-applications-with-fluent-and-material-styles/) - (September 28, 2020) -  This article will explain how to add either Material Design or Fluent Design to a new or existing Uno app with only a few lines of code, and help you boost your productivity with our ready-made styles and controls!

* [Sneak Peek at 2020 Volume 3: Major Highlights](https://www.syncfusion.com/blogs/post/sneak-peek-at-2020-volume-3-major-highlights.aspx) - (September 25, 2020) -  We are happy to announce that our first-ever Syncfusion Essential Studio for WinUI preview 3 will be included in our upcoming 2020 Volume 3 release. 

* [Feature roadmap of WinUI is finally available](https://mspoweruser.com/feature-roadmap-of-winui-is-finally-available/) - (September 24, 2020) -  Microsoft today announced the release of WinUI 3.0 feature roadmap. The feature roadmap table included below will offer you the status on WinUI 3 features, and the expected date of availability. 

* [Microsoft's WebView2 for Windows 10 apps will be generally available by end of 2020](https://www.windowscentral.com/microsofts-webview2-windows-10-apps-will-be-generally-available-end-2020) - (September 22, 2020) -  WebView2 should improve the performance of web apps that adopt it.

* [Announcing more ways, we’re making app development easier on Windows](https://blogs.windows.com/windowsdeveloper/2020/09/22/kevin-gallo-microsoft-ignite-2020/) - (September 22, 2020) -  Building great apps on Windows should be easier – no matter how your app is written.  We want to ensure you have a path forward to make your apps better on Windows and we’re doing that with Project Reunion.  We’re creating a unified app platform that allows you to focus on your app and take advantage of new or existing code.  We also know you need a great development environment and tools that help you stay productive. Today, at Microsoft Ignite I’m excited to share the progress we’ve made to simplify app development and give you a great developer experience.

* [Experimenting with .NET 5 Target Framework Names and the Windows platform](https://nicksnettravels.builttoroam.com/net-5-tfms/) - (September 19, 2020) - Firstly, if you haven’t been following the development of .NET 5 then you should definitely download the latest Visual Studio preview and .NET 5 preview SDK today. Next, you should follow the blogs from the dotnet team and specifically the post by Immo that discusses the future of .NET Standard. The post doesn’t just cover .NET Standard, it also covers the basics of how target framework names (TFMs) work in the .NET 5+ era. In this post we’re going to play around with this and take a look at some examples of different TFMs in action.

* [Windows 10 developers: Microsoft's Project Reunion just gained this new tool](https://www.zdnet.com/article/windows-10-developers-microsofts-project-reunion-just-gained-this-new-tool/) - (September 16, 2020) -  Microsoft unveils MRT Core resource loader for Project Reunion, its effort to fix problems with Win32 and UWP apps.

* [Building Windows Terminal with WinUI](https://devblogs.microsoft.com/commandline/building-windows-terminal-with-winui/) - (September 8, 2020) -  WinUI and Windows Terminal have a strong relationship that goes back to the origins of Windows Terminal. This blog post goes into the history and architecture of how these two technologies came together.

* [An update on my book - Learn WinUI 3.0](https://www.winui.tips/2020/09/an-update-on-my-book-learn-winui-30.html) - (September 4, 2020) -  Summer is winding down, and I realized it's been months since I have posted anything on my WPF, UWP, and WinUI Tips blogs. I have been hard at work writing my first book, Learn WinUI 3.0 from Packt Publishing, this year. The project started in January, and I am about to start writing the first draft of the fourteenth (and final) chapter. I haven't been given the exact publication date, but it should be available about the same time that Microsoft releases Preview 3 of WinUI 3 in November, maybe a little earlier.

* [App First Run Detection with Uno Platform and UWP](https://blog.mzikmund.com/2020/08/app-first-run-detection-with-uno-platform-and-uwp/) - (August 27, 2020) - Recently, James Montemagno published a blog post about the detection of first app run with Xamarin.Essentials. I thought it would be interesting to write a post about how the same would be accomplished with Uno Platform and UWP.

* [How to Move Uno Platform Pages to a Multi-Targeting Library](https://christianfindlay.com/2020/08/25/uno-multitargeting/) - (August 25, 2020) - You can move Uno Platform pages and other code into a multi-targeted library that you can reference from the Uno Platform head projects. This is much more convenient than using Visual Studio Shared libraries. Shared libraries don’t seem to have full support in Visual Studio, and some features like quick refactors often don’t work. This article briefly explains what I did to get this working. I completely removed the shared library in my sample.

* [Using WebAssembly Modules in C#](https://platform.uno/blog/using-webassembly-modules-in-c/) - (August 24, 2020) - This article covers implementing custom module validation in an ASP.NET Core MVC web application, using Emscripten to create a WebAssembly module that can be used outside the browser, and using WebAssembly modules in your C# code.

* [Running UWP on a Raspberry Pi Using Uno Platform](https://ian.bebbs.co.uk/posts/UnoPi) - (August 20, 2020) - A few days ago I showed how the recent v3 release of the Uno Platform allowed you to run UWP apps on Linux. This was fantastic but really only half the story I wanted to tell. What I really wanted to do was see if I could get an app written in my favourite UI framework running on my favourite SBC; to wit, UWP on the the Raspberry Pi. In this post I show how, yet again, the Uno team have made this not only possible but startlingly easy and shockingly powerful.

* [Bring the best of the Web to your .NET desktop applications with WebView2](https://devblogs.microsoft.com/dotnet/bring-the-best-of-the-web-to-your-net-desktop-applications-with-webview2/) - (August 19, 2020) - Last year at Build, we introduced WebView2, a browser control that renders web content (HTML / CSS / JavaScript) with the new Chromium-based Microsoft Edge. It was originally limited in scope to C/C++ applications. Today, we are happy to announce the release of the WebView2 preview for .NET applications! WebView2 is available for both .NET Core and .NET Framework. It can be used inside of WPF, Windows Forms and WinUI 3.0 applications all the way down to Windows 7.

* [Putting “Universal” back into UWP](https://medium.com/@Arlodottxt/putting-universal-back-into-uwp-d2e5a8099bc1) - (August 18, 2020) - As the UWP dream dwindles, Uno picks up the torch and takes it to new heights.

* [Now Out: Uno Platform 3.0 (C# + WinUI), Previewing Linux Support](https://visualstudiomagazine.com/articles/2020/08/18/uno-platform-3-0.aspx?m=1) - (August 18, 2020) - With an original focus on creating Universal Windows Platform (UWP) mobile apps, the Uno Platform is described as a UWP bridge that allows UWP-based code to run on Windows, WebAssembly, iOS, macOS, Android and Linux. 

* [UnoConf 2020](https://blog.mzikmund.com/2020/08/unoconf-2020/) - (August 18, 2020) - The second year of the official Uno Platform developer conference UnoConf was held on 12th August 2020. As opposed to last year’s edition, we couldn’t enjoy the beauty and culinary variety that is Montréal, as COVID-19 made sure to turn the event into a virtual-only conference. But even with this limitation UnoConf 2020 has easily beaten the high bar set by last year’s event and was definitely my favourite virtual conference so far! This article is my summary of the whole event but if you happened to miss it, don’t hesitate to play it back in all its glory at YouTube or with the handy embedded player below. Included in the article are also links to specific timestamps for each of the sessions.

* [ANNOUNNCING: Uno Platform 3.0 – Linux Support, Fluent, Material and more.](https://platform.uno/blog/announncing-uno-platform-3-0-linux-support-fluent-material-and-more/) - (August 13, 2020) - Today, at our annual UnoConf conference we announced several new major advancements and have laid out the vision for Uno Platform in H2 2020 and beyond. Our vision is to enable you to develop pixel-perfect, multi-platform applications using C# and WinUI. The 3.0 release brings us ever so closer to that vision.

* [On the incredible value proposition of .NET & the Uno Platform](https://ian.bebbs.co.uk/posts/UnoValue) - (August 12, 2020) - My company recently released Zenue; a solution for small businesses in the UK hospitality industry struggling to meet post-lockdown governmental guidance. In just 48 hours, a team of two were able to progress from initial concept to app-store submission having delivered on all the fundamental use-cases. In this post I show how this was made possible by .NET and the Uno Platform and why you should be considering these technologies for your next project.

* [Syncfusion’s First Control for Uno Platform: Charts](https://www.syncfusion.com/blogs/post/syncfusions-first-control-for-uno-platform-charts.aspx) - (August 5, 2020) - Syncfusion is happy to reveal the availability of its very first control for the Uno Platform, the Charts control. In this blog, we will provide a brief introduction to the Uno Platform, the key features of our Charts control, followed by the steps to integrate our Charts control in an Uno Platform application.

* [GitHub Actions for UWP apps – the Good, the Bad and the Ugly](http://www.dotnetapp.com/github-actions-for-uwp-apps-the-good-and-the-bad-and-the-ugly/) - (July 17, 2020) - I created a blank UWP app that is available at my GitHub. My Release Builder workflow allows the creation of a release version of a UWP app ready that can be submitted to Partner Center.

* [New Preview of WinUI 3, Native UI Platform of Windows, Fixes Stuff](https://visualstudiomagazine.com/articles/2020/07/17/winui-3-preview-2.aspx) - (July 17, 2020) - Microsoft shipped preview 2 of WinUI, the UI framework that uses Fluent Design to provide a native user experience (UX) framework for both Windows Desktop (Win32) and Universal Windows Platform (UWP) applications, focusing on stability and bug fixes.

* [Microsoft updates its 'Project Reunion' unified Windows platform with WinUI 3 Preview 2](https://www.zdnet.com/article/microsoft-updates-its-project-reunion-unified-windows-platform-with-winui-3-preview-2/) - (July 16, 2020) -  Microsoft is aiming to release a couple more WinUI previews later this year and plans to open source the WinUI 3 code in November.

* [WinUI 3 is Delayed to Spring 2021](https://www.thurrott.com/dev/237922/winui-3-is-delayed-to-spring-2021) - (July 16, 2020) - With the release today of WinUI 3 Preview 2, Microsoft has effectively delayed the final release from November 2020 to sometime in early 2021.

* [Announcing WinUI 3 Preview 2](https://blogs.windows.com/windowsdeveloper/2020/07/15/announcing-winui-3-preview-2/) - (July 15, 2020) - WinUI 3 Preview 2 was a quality and stability-driven release. It builds directly on Preview 1 by fixing quite a few critical and serious bugs that didn’t make the cut in time for our release at Build 2020 two months ago. The team wanted to put together a small release post-Build to make sure that WinUI 3 is stable and easy to use for everyone.

* [A deep-dive into WinUI 3 in desktop apps](https://blogs.windows.com/windowsdeveloper/2020/07/07/a-deep-dive-into-winui-3-in-desktop-apps/) - (July 7, 2020) - In this blog post I’m going to focus on building a desktop app with WinUI 3 Preview 1 and .NET, leaving C++ for future posts.

* [Highlighting dates in UWP CalendarView](https://blog.mzikmund.com/2020/07/highlighting-dates-in-uwp-calendarview/) - (July 1, 2020) - I have posted about UWP CalendarView control a while back. The previous post summarized how to customize calendar days while they are being assigned. A new StackOverflow question has prompted me to revisit this to show how already displayed dates can be adjusted as well.

* [Announcing: Rapid XAML Toolkit release 0.10](https://www.mrlacey.com/2020/06/announcing-rapid-xaml-toolkit-release.html) - (June 30, 2020) - Yes, 0.10 means it's getting excitingly close to a full 1.0 release and the removal of the preview tag. Wider events and that some of what I'm trying to do with the toolkit has turned out to be much, much harder than I originally expected and means it's taking longer than I hoped but progress is being made.

* [Future-proofing .NET application development with the Uno Platform](https://www.infoworld.com/article/3564790/future-proofing-net-application-development-with-the-uno-platform.html) - (June 30, 2020) - With support for WinUI 3.0, the cross-platform Uno development environment is an important alternative to Xamarin

* [What is Project Reunion?](https://github.com/microsoft/ProjectReunion/blob/master/docs/README.md) - (June 30, 2020) - Project Reunion is a set of libraries, frameworks, components, and tools that you can use in your apps to access powerful Windows platform functionality from all kinds of apps on many versions of Windows. Project Reunion combines the powers of Win32 native applications alongside modern API usage techniques, so your apps light up everywhere your users are.

* [Windows UI Testing With Legerity](https://www.jamescroft.co.uk/windows-ui-testing-with-legerity/) - (June 29, 2020) - Testing at the application’s UI level is often an afterthought for most projects. These tests usually put your application under the testing of how it would be used by a physical user.

* [UWP Community // Launch 2020](https://medium.com/@Arlodottxt/uwp-community-launch-2020-1772efb1e382) - (June 9, 2020) - An annual event hosted by the UWP Community Discord server, where developers in the community collaborate on and Launch their new and refreshed Windows 10 apps.

* [Help us improve WPF and UWP XAML designer](https://devblogs.microsoft.com/dotnet/help-us-improve-wpf-and-uwp-xaml-designer/) - (May 28, 2020) - We would like to make your experience developing WPF and UWP applications in Visual Studio better!

* [Microsoft brings WinUI to desktop apps: It's a landmark for Windows development, but it has taken far too long](https://www.theregister.com/2020/05/26/microsoft_winui_to_desktop/) - (May 26, 2020) - The look and feel of UWP without all the baggage.

* [Project Reunion: Microsoft's unified app strategy is still missing one piece](https://www.zdnet.com/article/project-reunion-microsofts-unified-app-strategy-is-still-missing-one-piece/) - (May 26, 2020) - At last week's virtual Build 2020, Microsoft showed off its vision for Project Reunion, a new API that combines Win32 and the Universal Windows Platform. It's still missing the most important piece, however.

* [Project Reunion: An End to Microsoft’s UI Madness?](https://medium.com/young-coder/project-reunion-an-end-to-microsofts-ui-madness-1af662e36386) - (May 22, 2020) - After years of confusion, Windows development is about to improve… slowly.

* [With Project Reunion Microsoft is Attempting to Unify Win32 and UWP APIs](https://www.infoq.com/news/2020/05/microsoft-project-reunion/?utm_campaign=infoq_content&utm_source=infoq&utm_medium=feed&utm_term=global) - (May 22, 2020) - As the following picture clarifies, with Project Reunion Microsoft is working to build new APIs on top of existing Win32 and UWP APIs to provide a common API layer independent from the underlying OS. Microsoft will distribute the new API as independent packages that can be bundled along with apps and used on a variety of Windows versions.

* [Microsoft Build 2020: Uno Platform + WinUI = Future of Cross Platform Apps](https://nicksnettravels.builttoroam.com/microsoft-build-2020-uno-platform-winui-future-of-cross-platform-apps/) - (May 20, 2020) - I’ve been a long time supporter of the work that the team at Uno Platform have been doing. The announcement today of v3.0 of the Uno Platform comes hot on the heals of releases 2.3 and 2.4 that introduced AndroidX and MacOS support. This isn’t just any old announcement, v3 aligns the Uno Platform with the preview of WinUI 3.

* [Improvements to XAML tooling in Visual Studio 2019 version 16.7 Preview 1](https://devblogs.microsoft.com/visualstudio/improvements-to-xaml-tooling-in-visual-studio-2019-version-16-7-preview-1/) - (May 20, 2020) - Hello once again from the XAML tooling team in Visual Studio. Given this week’s many new and exciting releases at Microsoft Build 2020 I want to take this opportunity to recap what’s new for those building WPF or UWP applications, and where applicable, Xamarin.Forms.

* [Announcing Uno Platform 3.0 – Support for WinUI 3.0 Preview 1](https://platform.uno/blog/announcing-uno-platform-3-0-support-for-winui-3-0-preview-1/) - (May 19, 2020) - Today, the Uno Platform is adding support for WinUI 3.0 Preview, alongside WinUI 2/UWP and later. This allows applications to use newer APIs from Microsoft and create cross platforms apps. We’ve worked closely together with the WinUI team in order to be able to bring you Uno Platform 3.0 release at the same time WinUI 3.0 Preview 1 is being announced at Microsoft Build 2020 conference.

* [Developing for all 1 billion Windows 10 devices and beyond](https://blogs.windows.com/windowsdeveloper/2020/05/19/developing-for-all-1-billion-windows-10-devices-and-beyond/?WT.mc_id=DX_MVP4025064) - (May 19, 2020) - Today, I will have the privilege of sharing how developers can build apps for modern work using Microsoft 365 and Windows platforms.

* [Introducing Telerik UI for WinUI Preview](https://www.telerik.com/blogs/introducing-telerik-ui-for-winui-preview) - (May 19, 2020) - Microsoft just announced the availability of WinUI 3.0 Preview on Build 2020. We are adding to that the announcement of the release of Telerik UI for WinUI Preview.

* [Introducing WinUI 3 Preview 1](https://blogs.windows.com/windowsdeveloper/2020/05/19/introducing-winui-3-preview-1/?WT.mc_id=DX_MVP4025064) - (May 19, 2020) - Today at Microsoft Build 2020 the WinUI team is excited to announce the latest version of WinUI 3 available for public preview: WinUI 3 Preview 1. This preview expands the world of WinUI to an even wider audience of developers – the previously-released WinUI 3 Alpha was only available to UWP app developers, but Preview 1 now enables WinUI usage in Desktop (Win32) apps as well!

* [Project Reunion Is Microsoft’s New Attempt at Unifying Windows 10 App Development](https://www.thurrott.com/microsoft/235282/project-reunion-is-microsofts-new-attempt-at-unifying-windows-10-app-development) - (May 19, 2020) - At Build 2020, Microsoft is introducing a new vision for unifying app development for Windows 10. The company’s latest attempt at unifying the app development experience for Windows 10 is called Project Reunion.

* [UWP, WinUI and Uno Platform get Prism support thanks to Uno team OSS Contribution](https://platform.uno/blog/uwp-winui-and-uno-platform-get-prism-support-thanks-to-uno-team-oss-contribution/) - (April 27, 2020) - We are pleased to announce that Uno Platform team has provided the initial support for the Prism library.

* [WinUI NumberBox Control](https://www.reflectionit.nl/blog/2020/winui-numberbox-control) - (March 27, 2020) - If you write business apps, there are a lot of controls for data input: TextBox, CheckBox, ComboBox, DatePicker, ToggleSwitch, TimePicker, RadioButton, Slider, etc. I always wondered why there was no NumberBox. Numeric input is very common so it needs its own control for it. Luckily there is the Windows UI Library (WinUI), an open source project from Microsoft. I proposed the NumberBox last year and the team did a great job implementing it. It is released in version 2.3 and most of the issues are now solved. Time for a blog post showing of its features.

* [Building Modern & Performant Desktop Apps—Is WinUI 3.0 the Way to Go?](https://www.telerik.com/blogs/building-modern-performant-desktop-apps-winui-30-the-way-to-go) - (March 23, 2020) - WinUI 3.0 is the hot new framework for desktop application development. In this post we’ll try to answer the questions “What is WinUI 3.0?”, “How different it is from WPF, UWP and WinForms?” and ultimately “What is the best framework for developing desktop applications?”

* [Window and Application API Spec](https://github.com/microsoft/microsoft-ui-xaml-specs/blob/Win32/active/Win32/Window_and_Application_API_Spec.md) - (March 16, 2020) - This spec describes updates to the XAML Window and Application APIs to accommodate this move to support Desktop (win32) apps.

* [Microsoft Emulator and Windows 10X Emulator Image (Preview) build 19578 available now!](https://blogs.windows.com/windowsdeveloper/2020/03/10/microsoft-emulator-and-windows-10x-emulator-image-preview-build-19578-available-now/?WT.mc_id=DX_MVP4025064) - (March 10, 2020) - Today we released new versions of both the Microsoft Emulator and the Windows 10X Emulator Image (Preview) to the Microsoft Store.

* ['Developers have lost hope Microsoft will do the right thing'... Redmond urged to make WinUI cross-platform](https://www.theregister.com/2020/02/28/winui_cross_platform/) - (February 28, 2020) - Microsoft's roadmap for developing Windows applications is opposed by some programmers who want to see a cross-platform solution, rather than just being Windows-only.

* [Calling WinUI from Blazor App Hosted in WebView2](https://www.thomasclaudiushuber.com/2020/02/19/calling-winui-from-blazor-app-hosted-in-webview2/) - (February 19, 2020) - But can you also call from the hosted Blazor app into your WinUI app? Of course you can. To show you how it works, I’ve extended the application from the previous blog post.

* [Hosting a Blazor App in WinUI 3 with WebView2 and call a Blazor Component Method from WinUI](https://www.thomasclaudiushuber.com/2020/02/18/hosting-blazor-app-in-winui-3-with-webview-2-and-call-blazor-component-method-from-winui/) - (February 18, 2020) - I thought I give WebView2 a try, and hey, why not trying to host a web app in WebView2 that is built with my favorite Single Page Application (SPA) framework: Blazor! But just hosting would be easy. I want to call a method in the Blazor App from my WinUI app.

* [Develop apps for Windows 10X dual-screen devices](https://docs.microsoft.com/en-us/dual-screen/windows/) - (February 11, 2020) - Download and install the Microsoft Emulator and tools to start developing and testing your apps for Windows 10X.

* [Microsoft shows off how containerized apps will work in Windows 10X](https://www.zdnet.com/article/microsoft-shows-off-how-containerized-apps-will-work-in-windows-10x/#ftag=RSSbaffb68) - (February 11, 2020) - Microsoft is delivering its promised Windows 10X emulator and SDK, plus a refresh of its Android-based Duo SDK as its next milestones along its dual-screen device path.

* [Advertising networks for UWP apps](https://blog.mzikmund.com/2020/02/advertising-networks-for-uwp-apps/) - (February 4, 2020) - Microsoft, unfortunately, threw in the proverbial towel with its Ad Monetization platform for UWP apps. While we are waiting for a more official and detailed statement and suggested transition path, what are the alternative advertising networks available for UWP we can use?

* [Modern XAML Development](https://www.mrlacey.com/2020/02/modern-xaml-development-notes-from.html) - (February 4, 2020) - Today (at the time of posting) I'm talking in Stokholm about Modern XAML Development. Here for your simple consumption are links to all the things I talked about, demonstrated or otherwise mentioned. [Slides are also available](https://www.mrlacey.com/2020/02/modern-xaml-development-slides-and.html).

* [Surface Duo – WinUI TwoPaneView implementation via Uno Platform](https://platform.uno/blog/surface-duo-winui-twopaneview-implementation-via-uno-platform/) - (February 3, 2020) - Uno Platform is in the position to be able to use the controls from WinUI (Our #WinUIEverywhere vision), and Microsoft is making development in the open for such devices in the form of the TwoPaneView control which allows us to experiment with it early and often.

* [Usability Matters for the Surface Neo and the Surface Duo](https://www.mrlacey.com/2020/01/usability-matters-for-surface-neo-and.html) - (January 23, 2020) - Before the new surface devices arrive and trying to avoid the hype, in this post, I want to use the structure and pointers from the book ([Usability Matters](https://www.manning.com/books/usability-matters)) to highlight important areas about which to think.

* [Announcing dual-screen preview SDKs and Microsoft 365 Developer Day](https://blogs.windows.com/windowsdeveloper/2020/01/22/announcing-dual-screen-preview-sdks-and-microsoft-365-developer-day/?WT.mc_id=DX_MVP4025064) - (January 22, 2020) - In November, we shared our vision for dual-screen devices and how this new device category will help people get more done on smaller and more mobile form factors. Today, we are excited to give you an update on how you can get started and optimize for dual-screen devices.
